
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: IsAddOnLoaded, pairs, Skada

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Integration Skada")

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	if not IsAddOnLoaded("Skada") then
		self:RegisterEvent("ADDON_LOADED")
		return
	end

	if not self:IsHooked(Skada, "Report") then
		self:RawHook(Skada, "Report", "Skada_Report")
	end

	self:RegisterFrames()
	self:RegisterMessage("SIXUI_CLUTTER_STATE_CHANGED")
end

function M:RegisterFrames()
	A:RegisterFrame("SkadaBarWindowDamage"):CreateBorder(C.BORDER_PADDING)
	A:RegisterFrame("SkadaBarWindowHealing"):CreateBorder(C.BORDER_PADDING)
end

-- Set Skada's columns.
function M:SetColumns(showAbsolute, showPercent, showPerSecond)
	if not Skada then return end

	for _, module in pairs({Skada.modules.Damage, Skada.modules.Healing}) do
		local c = module and module.metadata and module.metadata.columns

		if c then
			if module == Skada.modules.Damage then
				c.Damage = showAbsolute
				c.DPS = showPerSecond or not showAbsolute
			elseif module == Skada.modules.Healing then
				c.Healing = showAbsolute
				c.HPS = showPerSecond or not showAbsolute
			end

			c.Percent = showPercent or showAbsolute
		end
	end

	Skada:UpdateDisplay(true)
end

-------------------------------------------------------------------------------
-- Events
-------------------------------------------------------------------------------

function M:ADDON_LOADED(event, name)
	if name == "Skada" then
		self:UnregisterEvent("ADDON_LOADED")
		self:OnEnable()
	end
end

-- Update Skada's columns when the Control key is pressed or released.
function M:SIXUI_CLUTTER_STATE_CHANGED(event, state)
	self.isClutterKeyDown = state
	self:SetColumns(state)
	Skada:UpdateDisplay(true)
end

-------------------------------------------------------------------------------
-- Hooks
-------------------------------------------------------------------------------

-- Use a hook to show all of Skada's columns when printing a report.
function M:Skada_Report(...)
	self:SetColumns(true, true, true)
	self.hooks[Skada].Report(...)
	self:SetColumns(self.isClutterKeyDown)
end
